import type { ButtonHTMLAttributes, MouseEventHandler, ReactNode } from "react";
export interface ExpansionPanelHeaderProps extends ButtonHTMLAttributes<HTMLButtonElement> {
    /**
     * The id for the header. This is required for a11y.
     */
    id: string;
    /**
     * The icon to use for the expander icon.
     */
    icon?: ReactNode;
    /**
     * Boolean if the panel is currently expanded. This is just used to rotate the
     * icon as needed.
     */
    expanded: boolean;
    /**
     * The click handler that should attempt to toggle the expansion state of the
     * panel.
     */
    onClick: MouseEventHandler<HTMLButtonElement>;
    /**
     * The children to display within the header.
     *
     * Reminder: Since this is a `<button>`, only `inline` elements should be
     * rendered within (so use `<span>` instead of `<div>` for children).
     */
    children: ReactNode;
    /**
     * Boolean if the icon rotation transition should be disabled.
     */
    disableTransition?: boolean;
}
/**
 * The header for a panel that controls the expansion state. This is really just
 * a simple button that displays the children before an expander icon.
 *
 * Reminder: Since this is a `<button>`, only `inline` elements should be
 * rendered within (so use `<span>` instead of `<div>` for children).
 */
export declare const ExpansionPanelHeader: import("react").ForwardRefExoticComponent<ExpansionPanelHeaderProps & import("react").RefAttributes<HTMLButtonElement>>;
